=====
Usage
=====

To use WasabiCLI::

    $ pip install wasabicli

    $ wasabicli


Once installed via pip, usage is as simply running the command to start the application.

This has made easy enough for technical and non-technical users.
